<?php
/*!
	@file
		Classes for PDO support
*/

require_once("db_common.php");
/*! Wrapper around PDO connection
**/
class PDODBWrapper extends DBWrapper{
	private $last_result;//!< store result or last operation
	function query($sql,$result=false){ 
		//may cause problems for tree
		if ($this->last_result)
			$this->last_result->closeCursor();
		
		if (is_object($sql))
			$sql=$sql->sql();
		
		$this->logger->log("Exec SQL: ",$sql);
		$this->last_result=$res=$this->db->query($sql);
		if (!$res){
			$error = $this->db->errorInfo();
			$this->logger->log("PDO error: ",$error[2]);
			return false;
		}
		if ($result===false)
			return $res;
		else 
			return $res->fetchColumn($result);
	}	
	function escape($str){
		$res=$this->db->quote($str);
		if ($res===false) //not supported by pdo driver
			return str_replace("'","''",$str); 
		return substr($res,1,-1);
	}	
	function get_data_array($res){
		return $res->fetch(PDO::FETCH_NUM);
	}
	function get_data_named($res){
		return $res->fetch(PDO::FETCH_ASSOC);
	}
	function get_id(){
		return $this->db->lastInsertId();
	}
	function count($res){
		return $res->rowCount();	
	}
	/*! Returns the name of used DB Driver
		@returns name of DB driver
	**/
	function get_driver(){
		 return $this->db->getAttribute(PDO::ATTR_DRIVER_NAME);
	}
}
/*! Generator of select queries for PDO connection
**/	
class DBQueryPDO extends DBQuery{
	//redefined to support Oracle's way of row count limitation
	public function sql(){ 
		$str="SELECT ".$this->select." FROM ".$this->table;
		if (sizeof($this->rules))
			$str.=" WHERE ".implode(" AND ",$this->rules);
		if ($this->group_by)
			$str.=" GROUP BY ".$this->group_by;
		if ($this->order)
			$str.=" ORDER BY ".$this->order;
		if ($this->count){
			$str="SELECT * FROM ( select /*+ FIRST_ROWS(".$this->count.")*/dhx_table.*, ROWNUM rnum FROM (".$str.") dhx_table where ROWNUM <= ".($this->count+$this->from)." ) where rnum >".$this->from;
		}
		return $str;
	}	
}

?>